@@ -294,7 +294,7 @@ class PyCMakeBuild(object):
         install_full_path = Path(self.__install_path)
         install_full_path = install_full_path.joinpath(self.__arch)
         install_full_path = install_full_path.joinpath(build_type.value)
-        install_full_path = install_full_path.joinpath(name)
+        install_full_path = install_full_path.joinpath(name + ("_wasm" if emcmake else ""))
         print(f"[编译信息]:{name}/{build_type.value}")
 
         print(f"[工程路径]:{abs_source_path}")
@@ -304,7 +304,7 @@ class PyCMakeBuild(object):
             os.makedirs(install_full_path.absolute().as_posix())
 
         build_full_dir = (
-            f"{self.__build_dir}/{name}/build_{self.__arch}_{build_type.value}"
+            f"{self.__build_dir}/{name}/build{"_wasm" if emcmake else ""}_{self.__arch}_{build_type.value}"
         )
         print(f"[临时路径]:{build_full_dir}")
         if not os.path.exists(build_full_dir):
